-- Table: registry
CREATE TABLE registry
(
  uuid character varying(300) NOT NULL,
  uri_name character varying(300),
  registrymanager character varying(300),
  datecreation timestamp without time zone,
  datelastupdate timestamp without time zone,
  base_uri character varying(200),
  CONSTRAINT registry_pkey PRIMARY KEY (uuid)
)
WITH (
  OIDS=FALSE
);

-- Table: changelog
CREATE TABLE changelog
(
  uuid character varying(50) NOT NULL,
  item_id character varying(50) NOT NULL,
  message text NOT NULL,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  CONSTRAINT pk_changelog PRIMARY KEY (uuid),
  CONSTRAINT fk_changelog_item FOREIGN KEY (item_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_changelog_item_id FOREIGN KEY (item_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);

-- Table: customattribute
CREATE TABLE customattribute
(
  uuid character varying(50) NOT NULL,
  name character varying(200) NOT NULL,
  required boolean NOT NULL DEFAULT false,
  multivalue boolean NOT NULL DEFAULT false,
  coded boolean NOT NULL DEFAULT false,
  isforeignkey boolean NOT NULL DEFAULT false,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  itemclass_id character varying(50) NOT NULL,
  CONSTRAINT pk_customattribute PRIMARY KEY (uuid),
  CONSTRAINT fk_customattribute_itemclass_id FOREIGN KEY (itemclass_id)
      REFERENCES itemclass (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_itemclassid FOREIGN KEY (itemclass_id)
      REFERENCES itemclass (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);

-- Table: customattributecode
CREATE TABLE customattributecode
(
  uuid character varying(50) NOT NULL,
  customattribute_id character varying(50) NOT NULL,
  value character varying(200) NOT NULL,
  CONSTRAINT pk_customattributecode PRIMARY KEY (uuid),
  CONSTRAINT fk_customattributecode_customattribute FOREIGN KEY (customattribute_id)
      REFERENCES customattribute (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_customattributecode_customattribute_id FOREIGN KEY (customattribute_id)
      REFERENCES customattribute (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);

-- Table: customattributevalue
CREATE TABLE customattributevalue
(
  uuid character varying(50) NOT NULL,
  customattribute_id character varying(50) NOT NULL,
  item_id character varying(50) NOT NULL,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  CONSTRAINT pk_customattributevalues PRIMARY KEY (uuid),
  CONSTRAINT fk_customattributevalue_customattribute_id FOREIGN KEY (customattribute_id)
      REFERENCES customattribute (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_customattributevalue_item_id FOREIGN KEY (item_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_customattributevalues_customattribute FOREIGN KEY (customattribute_id)
      REFERENCES customattribute (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_customattributevalues_item FOREIGN KEY (item_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);

-- Table: item
CREATE TABLE item
(
  uuid character varying(50) NOT NULL,
  register_id character varying(50) NOT NULL,
  itemclass_id character varying(50) NOT NULL,
  status_id character varying(50) NOT NULL,
  parent_id character varying(50),
  collection_id character varying(50),
  predecessor_id character varying(50),
  successor_id character varying(50),
  uri_name character varying(200) NOT NULL,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  datetimeaddition timestamp without time zone,
  datetimesupersession timestamp without time zone,
  datetimeretirment timestamp without time zone,
  datetimeinvalidation timestamp without time zone,
  CONSTRAINT pk_item PRIMARY KEY (uuid),
  CONSTRAINT fk_item_collection_id FOREIGN KEY (collection_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_item_collection FOREIGN KEY (collection_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_item_parent FOREIGN KEY (parent_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_item_predecessor FOREIGN KEY (predecessor_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_item_successor FOREIGN KEY (successor_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_itemclass FOREIGN KEY (itemclass_id)
      REFERENCES itemclass (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_itemclass_id FOREIGN KEY (itemclass_id)
      REFERENCES itemclass (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_parent_id FOREIGN KEY (parent_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_predecessor_id FOREIGN KEY (predecessor_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_register FOREIGN KEY (register_id)
      REFERENCES register (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_register_id FOREIGN KEY (register_id)
      REFERENCES register (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_status FOREIGN KEY (status_id)
      REFERENCES status (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_status_id FOREIGN KEY (status_id)
      REFERENCES status (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_item_successor_id FOREIGN KEY (successor_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);

-- Table: itemclass
CREATE TABLE itemclass
(
  uuid character varying(50) NOT NULL,
  register_id character varying(50) NOT NULL,
  uri_name character varying(200) NOT NULL,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  ordernumber integer NOT NULL DEFAULT 0,
  CONSTRAINT pk_itemclass PRIMARY KEY (uuid),
  CONSTRAINT fk_itemclass_register FOREIGN KEY (register_id)
      REFERENCES register (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_itemclass_register_id FOREIGN KEY (register_id)
      REFERENCES register (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT uq_itemclass_uri_name UNIQUE (uri_name)
)
WITH (
  OIDS=FALSE
);

-- Table: languagecode
CREATE TABLE languagecode
(
  uuid character varying(50) NOT NULL,
  label character varying(200) NOT NULL,
  isocode character varying(200),
  CONSTRAINT pk_language PRIMARY KEY (uuid),
  CONSTRAINT uq_language_isocode UNIQUE (isocode),
  CONSTRAINT uq_language_label UNIQUE (label)
)
WITH (
  OIDS=FALSE
);

-- Table: localization
CREATE TABLE localization
(
  uuid character varying(50) NOT NULL,
  item_id character varying(50),
  itemclass_id character varying(50),
  language_id character varying(50) NOT NULL,
  register_id character varying(50),
  customattributevalue_id character varying(50),
  label character varying(300) NOT NULL,
  definition text,
  description text,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  registry_id character varying(50),
  CONSTRAINT pk_itemlanguage PRIMARY KEY (uuid),
  CONSTRAINT fk_itemlanguage_customattributevalue FOREIGN KEY (customattributevalue_id)
      REFERENCES customattributevalue (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_itemlanguage_item FOREIGN KEY (item_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_itemlanguage_itemclass FOREIGN KEY (itemclass_id)
      REFERENCES itemclass (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_itemlanguage_language FOREIGN KEY (language_id)
      REFERENCES languagecode (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_itemlanguage_register FOREIGN KEY (register_id)
      REFERENCES register (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_localization_customattributevalue_id FOREIGN KEY (customattributevalue_id)
      REFERENCES customattributevalue (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_localization_item_id FOREIGN KEY (item_id)
      REFERENCES item (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_localization_itemclass_id FOREIGN KEY (itemclass_id)
      REFERENCES itemclass (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_localization_language_id FOREIGN KEY (language_id)
      REFERENCES languagecode (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_localization_register_id FOREIGN KEY (register_id)
      REFERENCES register (uuid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITH (
  OIDS=FALSE
);

-- Table: register
CREATE TABLE register
(
  uuid character varying(50) NOT NULL,
  base_uri character varying(350),
  uri_name character varying(200) NOT NULL,
  datecreation timestamp without time zone NOT NULL DEFAULT now(),
  datelastupdate timestamp without time zone,
  registerowner character varying(300),
  registermanager character varying(300),
  registercontrolbody character varying(300),
  registry_id character varying,
  CONSTRAINT pk_register PRIMARY KEY (uuid),
  CONSTRAINT uq_register_base_uri UNIQUE (base_uri),
  CONSTRAINT uq_register_uri_name UNIQUE (uri_name)
)
WITH (
  OIDS=FALSE
);

-- Table: status
CREATE TABLE status
(
  uuid character varying(50) NOT NULL,
  label character varying(200) NOT NULL,
  uri character varying(200),
  CONSTRAINT pk_status PRIMARY KEY (uuid),
  CONSTRAINT uq_status_label UNIQUE (label)
)
WITH (
  OIDS=FALSE
);