/*
* Copyright 2010,2013 EUROPEAN UNION
* Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
* the European Commission - subsequent versions of the EUPL (the "Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
*
* http://ec.europa.eu/idabc/eupl
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the Licence is distributed on an "AS IS" basis,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the Licence for the specific language governing permissions and
* limitations under the Licence.
*
* Date: 14/06/2013
* Authors: European Commission, Joint Research Centre
* Daniele Francioli, Emanuela Epure
* inspire-registry-info@jrc.ec.europa.eu
*
* This work was supported by the EU  Interoperability Solutions for
* European Public Administrations Programme (http://ec.europa.eu/isa)
* through Action 1.17: Re-usable INSPIRE Reference Platform 
* (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
*/

package eu.europa.ec.re3gistry.model;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

@Entity
@Table(name = "changelog", catalog = "inspireregistry", schema = "public")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Changelog.findAll", query = "SELECT c FROM Changelog c"),
    @NamedQuery(name = "Changelog.findByUuid", query = "SELECT c FROM Changelog c WHERE c.uuid = :uuid"),
    @NamedQuery(name = "Changelog.findByMessage", query = "SELECT c FROM Changelog c WHERE c.message = :message"),
    @NamedQuery(name = "Changelog.findByDatecreation", query = "SELECT c FROM Changelog c WHERE c.datecreation = :datecreation"),
    @NamedQuery(name = "Changelog.findByDatelastupdate", query = "SELECT c FROM Changelog c WHERE c.datelastupdate = :datelastupdate")})
public class Changelog implements Serializable {

    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    @Basic(optional = false)
    @Column(name = "message")
    private String message;
    @Basic(optional = false)
    @Column(name = "datecreation")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datecreation;
    @Column(name = "datelastupdate")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datelastupdate;
    @JoinColumn(name = "item_id", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Item item;

    public Changelog() {
    }

    public Changelog(String uuid) {
        this.uuid = uuid;
    }

    public Changelog(String uuid, String message, Date datecreation) {
        this.uuid = uuid;
        this.message = message;
        this.datecreation = datecreation;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

    public Item getItem() {
        return item;
    }

    public void setItem(Item item) {
        this.item = item;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Changelog)) {
            return false;
        }
        Changelog other = (Changelog) object;
        if ((this.uuid == null && other.uuid != null) || (this.uuid != null && !this.uuid.equals(other.uuid))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistry.model.Changelog[ uuid=" + uuid + " ]";
    }
}
