/*
 * Copyright 2010,2013 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 14/06/2013
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistry.re3gistryexport.marshaller;

import eu.europa.ec.re3gistry.constants.EntityNames;
import eu.europa.ec.re3gistry.jaxbmodel.register.CollectionLabelList;
import eu.europa.ec.re3gistry.jaxbmodel.register.ItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.StatusLabel;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.ApplicationschemaAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.CodelistAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.LabelAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.RegisterAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.RegistryAttribute;
import eu.europa.ec.re3gistry.model.Customattributevalue;
import eu.europa.ec.re3gistry.model.Item;
import eu.europa.ec.re3gistry.model.Itemclass;
import eu.europa.ec.re3gistry.model.Languagecode;
import eu.europa.ec.re3gistry.model.Localization;
import eu.europa.ec.re3gistry.model.Register;
import eu.europa.ec.re3gistry.model.Registry;
import eu.europa.ec.re3gistry.model.Status;
import java.io.File;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.persistence.EntityManager;
import javax.persistence.Query;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.PropertyException;

public class CodelistExport {

    private String folderSeparator = System.getProperty("file.separator");
    private final String folderExport;
    private final EntityManager em;
    private final List<Item> itemList;

    public CodelistExport(String folderExport, EntityManager em, List<Item> itemList) {
        this.folderExport = folderExport;
        this.em = em;
        this.itemList = itemList;
    }

    public HashMap<String, ArrayList<ItemLabel>> getHash() {
        HashMap<String, ArrayList<ItemLabel>> hashItemLabel = new HashMap<String, ArrayList<ItemLabel>>();
        File exportFile = new File(folderExport);
        if (!exportFile.exists()) {
            exportFile.mkdir();
        }

        if (!itemList.isEmpty()) {
            for (Item item : itemList) {
                try {
                    /**
                     * item details
                     */
                    String itemUUID = item.getUuid();
                    String itemUriName = item.getUriName();
                    Date itemDatecreation = item.getDatecreation();
                    Date itemDatelastupdate = item.getDatelastupdate();
                    Status itemStatus = item.getStatus();
                    Itemclass itemItemClass = item.getItemclass();
                    Item itemSuccessor = item.getSuccessor();
                    Register itemRegister = item.getRegister();
                    Item itemPredecessor = item.getPredecessor();
                    Item itemParent = item.getParent();
                    Item itemCollection = item.getCollection();

                    /**
                     * create a new ItemLabel
                     */
                    String ITEM_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.item = :item";
                    Query qil = em.createQuery(ITEM_LOCALIZATION_QUERY);
                    qil.setParameter("item", item);

                    List<Localization> itemLocalizationList = qil.getResultList();
                    for (Localization localization : itemLocalizationList) {
                        /**
                         * create ItemLabel
                         */
                        ItemLabel itemLabel = new ItemLabel();
                        itemLabel.setUuid(itemUUID);
                        itemLabel.setUri_name(itemUriName);
                        itemLabel.setDatecreation(itemDatecreation);
                        itemLabel.setDatelastupdate(itemDatelastupdate);

                        String localizationUUID = localization.getUuid();
                        Item localizationItem = localization.getItem();
                        Itemclass localizationItemClass = localization.getItemclass();
                        Languagecode localizationLanguage = localization.getLanguage();
                        Register localizationRegister = localization.getRegister();
                        Customattributevalue localizationCustomattribute = localization.getCustomattributevalue();
                        String localizationLabel = localization.getLabel();
                        String localizationDefinition = localization.getDefinition();
                        String localizationDescription = localization.getDescription();
                        Date localizationDatecreation = localization.getDatecreation();
                        Date localizationDatelastupdate = localization.getDatelastupdate();
                        String localizationLanguageIsocode = localizationLanguage.getIsocode();

                        StatusLabel statusLabel = new StatusLabel();
                        statusLabel.setUuid(itemStatus.getUuid());
                        statusLabel.setLabelAttribute(itemStatus.getLabel(), localizationLanguageIsocode);
                        statusLabel.setUri(itemStatus.getUri());

                        itemLabel.setStatus(statusLabel);
                        itemLabel.setLabel(localizationLabel, localizationLanguageIsocode);
                        itemLabel.setDefinition(localizationDefinition, localizationLanguageIsocode);
                        itemLabel.setDescription(localizationDescription, localizationLanguageIsocode);

                        /**
                         * set register
                         */
                        setRegister(itemRegister, em, localizationLanguage, itemLabel);

                        /**
                         * set the codelist if the collection is NOT NULL
                         */
                        setCodelist(itemCollection, em, localizationLanguage, itemLabel);

                        /**
                         * ITEMCLASS
                         */
                        ExportUtility.insertItemClass(itemItemClass, em, itemLabel, localizationLanguage);

                        /**
                         * PARENT
                         */
                        ExportUtility.insertParent(itemParent, em, itemLabel);

                        /**
                         * PREDECESSOR
                         */
                        ExportUtility.insertPredecessor(itemPredecessor, em, itemLabel);

                        /**
                         * SUCCESSOR
                         */
                        ExportUtility.insertSuccessor(itemSuccessor, em, itemLabel);

                        /**
                         * CUSTOM ATTRIBUTE
                         */
                        ExportUtility.insertCustomAttribute(em, item, itemLabel, localizationLanguage);

                        /**
                         * COLLECTION
                         */
                        File itemFile = insertCollection(item, exportFile, itemLabel, em, localizationLanguage, localizationLabel);

                        /**
                         * create XML
                         */
                        createXML(itemFile, itemLabel);

                        if (itemCollection == null) {
                            if (hashItemLabel.containsKey(localizationLanguageIsocode)) {
                                hashItemLabel.get(localizationLanguageIsocode).add(itemLabel);
                            } else {
                                ArrayList<ItemLabel> array = new ArrayList<ItemLabel>();
                                array.add(itemLabel);
                                hashItemLabel.put(localizationLanguageIsocode, array);
                            }
                        }
                    }
                } catch (JAXBException ex) {
                    Logger.getLogger(CodelistExport.class.getName()).log(Level.SEVERE, ex.getMessage(), ex);
                }
            }
        }



        return hashItemLabel;
    }

    private File insertCollection(Item item, File exportFile, ItemLabel itemLabel, EntityManager em, Languagecode localizationLanguageItem, String localizationLabel) {
        Item itemCollection = item.getCollection();
        String itemFileName;
        File itemFile;
        /**
         * COLLECTION if the collection is not null we have a VALUE of the
         * codelist
         */
        if (itemCollection != null) {
            String itemCollectionUUID = itemCollection.getUuid();
            String itemCollectionUriName = itemCollection.getUriName();

            ItemLabel collectionItemLabel = new ItemLabel();
            collectionItemLabel.setUuid(itemCollectionUUID);
            collectionItemLabel.setUri_name(itemCollectionUriName);

            /**
             * create the VALUES folder
             */
            itemFileName = exportFile.getAbsolutePath().concat(folderSeparator + itemCollectionUriName);
            itemFile = new File(itemFileName);
            if (!itemFile.exists()) {
                itemFile.mkdir();
            }

            itemFileName = itemFile.getAbsolutePath().concat(folderSeparator + itemLabel.getUri_name());
            itemFile = new File(itemFileName);
            if (!itemFile.exists()) {
                itemFile.mkdir();
            }
        } else {
            /**
             * create the name for the item which is not a value
             */
            itemFileName = exportFile.getAbsolutePath().concat(folderSeparator + itemLabel.getUri_name());
            itemFile = new File(itemFileName);
            if (!itemFile.exists()) {
                itemFile.mkdir();
            }

            String COLLECTION_ITEMCLASS_QUERY = "SELECT it FROM " + EntityNames.ENTITY_ITEM + " it WHERE it.collection = :item";
            Query qcicl = em.createQuery(COLLECTION_ITEMCLASS_QUERY);
            qcicl.setParameter("item", item);
            List<Item> itemList = qcicl.getResultList();

            if (!itemList.isEmpty()) {
                ArrayList<ItemLabel> arrayListItemLabel = new ArrayList<ItemLabel>();
                for (Item childitem : itemList) {
                    String CHILDITEM_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.item = :childitem  AND loc.language = :language";
                    Query qrlc = em.createQuery(CHILDITEM_LOCALIZATION_QUERY);
                    qrlc.setParameter("childitem", childitem);
                    qrlc.setParameter("language", localizationLanguageItem);

                    List<Localization> childitemLocalizationList = qrlc.getResultList();
                    if (!childitemLocalizationList.isEmpty() && childitemLocalizationList.size() == 1) {
                        String childitemlanguageIsocode = childitemLocalizationList.get(0).getLanguage().getIsocode();

                        ItemLabel childItemLabel = new ItemLabel();

                        childItemLabel.setUuid(childitem.getUuid());
                        childItemLabel.setUri_name(childitem.getUriName());
                        childItemLabel.setDatecreation(childitem.getDatecreation());
                        childItemLabel.setDatelastupdate(childitem.getDatelastupdate());

                        StatusLabel statusLabel = new StatusLabel();
                        statusLabel.setUuid(childitem.getStatus().getUuid());
                        statusLabel.setLabelAttribute(childitem.getStatus().getLabel(), childitemlanguageIsocode);
                        statusLabel.setUri(childitem.getStatus().getUri());

                        childItemLabel.setStatus(statusLabel);
                        childItemLabel.setLabel(childitemLocalizationList.get(0).getLabel(), childitemlanguageIsocode);
                        childItemLabel.setDescription(childitemLocalizationList.get(0).getDescription(), childitemlanguageIsocode);
                        childItemLabel.setDefinition(childitemLocalizationList.get(0).getDefinition(), childitemlanguageIsocode);

                        /**
                         * set codelist
                         */
                        String codeListUriName = item.getUriName();
                        CodelistAttribute codelistAttribute = new CodelistAttribute();
                        codelistAttribute.setUri_name(codeListUriName);
                        LabelAttribute labelAttribute = new LabelAttribute();
                        labelAttribute.setValue(localizationLabel);
                        labelAttribute.setLanguage(localizationLanguageItem.getIsocode());
                        codelistAttribute.setLabel(labelAttribute);
                        childItemLabel.setCodelist(codelistAttribute);

                        Register register = item.getRegister();

                        String registerBaseUri = register.getBaseUri();
                        String registerUriName = register.getUriName();

                        RegisterAttribute registerAttribute = new RegisterAttribute();
                        registerAttribute.setBase_uri(registerBaseUri);
                        registerAttribute.setUri_name(registerUriName);

                        String REGISTER_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.register = :register";
                        Query qrel = em.createQuery(REGISTER_LOCALIZATION_QUERY);
                        qrel.setParameter("register", item.getRegister());

                        List<Localization> localizationRegisterList = qrel.getResultList();
                        for (Localization registerlocalization : localizationRegisterList) {
                            if (registerlocalization.getLanguage().equals(localizationLanguageItem)) {
                                LabelAttribute registerlabelAttribute = new LabelAttribute();
                                registerlabelAttribute.setValue(registerlocalization.getLabel());
                                registerlabelAttribute.setLanguage(registerlocalization.getLanguage().getIsocode());
                                registerAttribute.setLabel(registerlabelAttribute);
                            }
                        }

                        RegistryAttribute registryAttribute = new RegistryAttribute();
                        Registry registry = register.getRegistry();
                        registryAttribute.setBase_uri(registry.getBaseUri());
                        registryAttribute.setUri_name(registry.getUriName());

                        String REGISTER_LOCALIZATION = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.registry = :registry";
                        Query qr = em.createQuery(REGISTER_LOCALIZATION);
                        qr.setParameter("registry", registry);

                        List<Localization> registerLocalization = qr.getResultList();
                        for (Localization registerLocalizationItem : registerLocalization) {
                            String registerLocalizationItemLabel = registerLocalizationItem.getLabel();
                            Languagecode registerLocalizationItemLanguage = registerLocalizationItem.getLanguage();

                            LabelAttribute registerlabelAttribute = new LabelAttribute();
                            registerlabelAttribute.setValue(registerLocalizationItemLabel);
                            registerlabelAttribute.setLanguage(registerLocalizationItemLanguage.getIsocode());

                            registryAttribute.setLabel(registerlabelAttribute);
                        }

                        registerAttribute.setRegistry(registryAttribute);
                        /**
                         *
                         */
                        childItemLabel.setRegister(registerAttribute);

                        /**
                         * ITEMCLASS
                         */
                        ExportUtility.insertItemClass(childitem.getItemclass(), em, childItemLabel, childitemLocalizationList.get(0).getLanguage());

                        /**
                         * PARENT
                         */
                        ExportUtility.insertParent(childitem.getParent(), em, childItemLabel);

                        /**
                         * PREDECESSOR
                         */
                        ExportUtility.insertPredecessor(childitem.getPredecessor(), em, childItemLabel);

                        /**
                         * SUCCESSOR
                         */
                        ExportUtility.insertSuccessor(childitem.getSuccessor(), em, childItemLabel);

                        /**
                         * CUSTOM ATTRIBUTE
                         */
                        ExportUtility.insertCustomAttribute(em, childitem, childItemLabel, childitemLocalizationList.get(0).getLanguage());

                        arrayListItemLabel.add(childItemLabel);
                    }
                }

                /**
                 * for the codelist set the collection and the register
                 */
                CollectionLabelList collectionLabelList = new CollectionLabelList();
                collectionLabelList.setItemLabel(arrayListItemLabel);
                itemLabel.setCollection(collectionLabelList);

            }
        }
        return itemFile;
    }

    private void createXML(File itemFile, ItemLabel itemLabel) throws PropertyException, JAXBException {
        /**
         * write the XML file
         */
        JAXBContext jaxbContextLang = JAXBContext.newInstance(ItemLabel.class);
        Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
        marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);

        File completeCodelistNameXML = new File(itemFile.getAbsolutePath().concat(folderSeparator + itemLabel.getUri_name() + "." + itemLabel.getLabel().getLanguage() + ".xml"));
        marshallerclassLanguage.marshal(itemLabel, completeCodelistNameXML);
    }

    private void setCodelist(Item itemCollection, EntityManager em, Languagecode localizationLanguage, ItemLabel itemLabel) {
        if (itemCollection != null) {
            String codeListUriName = itemCollection.getUriName();

            String PARENTITEM_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.item = :itemCollection  AND loc.language = :localizationLanguage";
            Query parentlc = em.createQuery(PARENTITEM_LOCALIZATION_QUERY);
            parentlc.setParameter("itemCollection", itemCollection);
            parentlc.setParameter("localizationLanguage", localizationLanguage);
            String parentItemLabel = ((Localization) parentlc.getResultList().get(0)).getLabel();

            CodelistAttribute codelistAttribute = new CodelistAttribute();
            codelistAttribute.setUri_name(codeListUriName);

            LabelAttribute labelAttribute = new LabelAttribute();
            labelAttribute.setValue(parentItemLabel);
            labelAttribute.setLanguage(localizationLanguage.getIsocode());

            codelistAttribute.setLabel(labelAttribute);

            itemLabel.setCodelist(codelistAttribute);
        }
    }

    private void setRegister(Register itemRegister, EntityManager em, Languagecode localizationLanguage, ItemLabel itemLabel) {
        String registerBaseUri = itemRegister.getBaseUri();
        String registerUriName = itemRegister.getUriName();

        RegisterAttribute registerAttribute = new RegisterAttribute();
        registerAttribute.setBase_uri(registerBaseUri);
        registerAttribute.setUri_name(registerUriName);

        String REGISTER_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.register = :register AND loc.language = :localizationLanguage";
        Query qrel = em.createQuery(REGISTER_LOCALIZATION_QUERY);
        qrel.setParameter("register", itemRegister);
        qrel.setParameter("localizationLanguage", localizationLanguage);

        List<Localization> localizationRegisterList = qrel.getResultList();
        for (Localization registerlocalization : localizationRegisterList) {
            LabelAttribute registerlabelAttribute = new LabelAttribute();
            registerlabelAttribute.setValue(registerlocalization.getLabel());
            registerlabelAttribute.setLanguage(registerlocalization.getLanguage().getIsocode());
            registerAttribute.setLabel(registerlabelAttribute);
        }

        RegistryAttribute registryAttribute = new RegistryAttribute();
        Registry registry = itemRegister.getRegistry();
        registryAttribute.setBase_uri(registry.getBaseUri());
        registryAttribute.setUri_name(registry.getUriName());

        String REGISTER_LOCALIZATION = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.registry = :registry AND loc.language = :localizationLanguage";
        Query qr = em.createQuery(REGISTER_LOCALIZATION);
        qr.setParameter("registry", registry);
        qr.setParameter("localizationLanguage", localizationLanguage);

        List<Localization> registerLocalization = qr.getResultList();
        for (Localization registerLocalizationItem : registerLocalization) {
            String registerLocalizationItemLabel = registerLocalizationItem.getLabel();
            Languagecode registerLocalizationItemLanguage = registerLocalizationItem.getLanguage();

            LabelAttribute labelAttribute = new LabelAttribute();
            labelAttribute.setValue(registerLocalizationItemLabel);
            labelAttribute.setLanguage(registerLocalizationItemLanguage.getIsocode());

            registryAttribute.setLabel(labelAttribute);
        }

        registerAttribute.setRegistry(registryAttribute);

        itemLabel.setRegister(registerAttribute);
    }
}