/*
* Copyright 2010,2013 EUROPEAN UNION
* Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
* the European Commission - subsequent versions of the EUPL (the "Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
*
* http://ec.europa.eu/idabc/eupl
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the Licence is distributed on an "AS IS" basis,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the Licence for the specific language governing permissions and
* limitations under the Licence.
*
* Date: 14/06/2013
* Authors: European Commission, Joint Research Centre
* Daniele Francioli, Emanuela Epure
* inspire-registry-info@jrc.ec.europa.eu
*
* This work was supported by the EU  Interoperability Solutions for
* European Public Administrations Programme (http://ec.europa.eu/isa)
* through Action 1.17: Re-usable INSPIRE Reference Platform 
* (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
*/
package eu.europa.ec.re3gistry.re3gistryexport.marshaller;

import eu.europa.ec.re3gistry.constants.EntityNames;
import eu.europa.ec.re3gistry.jaxbmodel.register.CustomattributeLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.CustomattributeLabelList;
import eu.europa.ec.re3gistry.jaxbmodel.register.ItemClassLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.ItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.ParentItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.PredecessorItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.SuccessorItemLabel;
import eu.europa.ec.re3gistry.model.Customattribute;
import eu.europa.ec.re3gistry.model.Customattributevalue;
import eu.europa.ec.re3gistry.model.Item;
import eu.europa.ec.re3gistry.model.Itemclass;
import eu.europa.ec.re3gistry.model.Languagecode;
import eu.europa.ec.re3gistry.model.Localization;
import eu.europa.ec.re3gistry.model.Register;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.Query;

public class ExportUtility {

    public static void insertItemClass(Itemclass itemClass, EntityManager em, ItemLabel itemLabel, Languagecode localizationLanguage) {
        /**
         * ITEMCLASS
         */
        if (itemClass != null) {
            ItemClassLabel itemclasslabel = new ItemClassLabel();
            itemclasslabel.setUuid(itemClass.getUuid());
            itemclasslabel.setUri_name(itemClass.getUriName());
            /**
             * get from Localization table the row with itemclass and language
             */
            String ITEMCLASS_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.itemclass = :itemclass AND loc.language = :localizationLanguage";
            Query qicl = em.createQuery(ITEMCLASS_LOCALIZATION_QUERY);
            qicl.setParameter("itemclass", itemClass);
            qicl.setParameter("localizationLanguage", localizationLanguage);
            List<Localization> itemclassLocalizationList = qicl.getResultList();
            if (itemclassLocalizationList.size() == 1) {
                for (Localization localizationitemclass : itemclassLocalizationList) {
                    itemclasslabel.setLabelAttribute(localizationitemclass.getLabel(), localizationitemclass.getLanguage().getIsocode());
                }
            }
            itemLabel.setItemclass(itemclasslabel);
        }
    }

    public static void insertParent(Item itemParent, EntityManager em, ItemLabel itemLabel) {
        /**
         * PARENT
         */
        if (itemParent != null) {
            ParentItemLabel parentItemLabel = new ParentItemLabel();
            ItemLabel parentLabel = new ItemLabel();
            parentLabel.setUuid(itemParent.getUuid());
            parentLabel.setUri_name(itemParent.getUriName());

            ItemClassLabel parentitemclasslabel = new ItemClassLabel();
            Itemclass itemparentitemclass = itemParent.getItemclass();
            parentitemclasslabel.setUuid(itemparentitemclass.getUuid());
            parentitemclasslabel.setUri_name(itemparentitemclass.getUriName());

            String PARENT_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE it.itemclass = :itemclass";
            Query qpl = em.createQuery(PARENT_LOCALIZATION_QUERY);
            qpl.setParameter("itemclass", itemparentitemclass);
            List<Localization> itemparentLocalizationList = qpl.getResultList();
            if (itemparentLocalizationList.size() == 1) {
                for (Localization itemparentLocalization : itemparentLocalizationList) {
                    parentitemclasslabel.setLabelAttribute(itemparentLocalization.getLabel(), itemparentLocalization.getLanguage().getIsocode());
                }
            }
            parentLabel.setItemclass(parentitemclasslabel);
            parentItemLabel.setItemlabel(parentLabel);
            itemLabel.setParent(parentItemLabel);
        }
    }

    public static void insertPredecessor(Item itemPredecessor, EntityManager em, ItemLabel itemLabel) {
        /**
         * PREDECESSOR
         */
        if (itemPredecessor != null) {
            PredecessorItemLabel predecessorItemLabel = new PredecessorItemLabel();
            ItemLabel predecessorLabel = new ItemLabel();
            predecessorLabel.setUuid(itemPredecessor.getUuid());
            predecessorLabel.setUri_name(itemPredecessor.getUriName());

            ItemClassLabel predecessoritemclasslabel = new ItemClassLabel();
            Itemclass itempredecessoritemclass = itemPredecessor.getItemclass();
            predecessoritemclasslabel.setUuid(itempredecessoritemclass.getUuid());
            predecessoritemclasslabel.setUri_name(itempredecessoritemclass.getUriName());

            String PREDECESSOR_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE it.itemclass = :itemclass";
            Query qprl = em.createQuery(PREDECESSOR_LOCALIZATION_QUERY);
            qprl.setParameter("itemclass", itempredecessoritemclass);
            List<Localization> itempredecessorLocalizationList = qprl.getResultList();
            if (itempredecessorLocalizationList.size() == 1) {
                for (Localization itempredecessorLocalization : itempredecessorLocalizationList) {
                    predecessoritemclasslabel.setLabelAttribute(itempredecessorLocalization.getLabel(), itempredecessorLocalization.getLanguage().getIsocode());
                }
            }
            predecessorLabel.setItemclass(predecessoritemclasslabel);
            predecessorItemLabel.setItemlabel(predecessorLabel);
            itemLabel.setPredecessor(predecessorItemLabel);
        }
    }

    public static void insertSuccessor(Item itemSuccessor, EntityManager em, ItemLabel itemLabel) {
        /**
         * SUCCESSOR
         */
        if (itemSuccessor != null) {
            SuccessorItemLabel successorItemLabel = new SuccessorItemLabel();
            ItemLabel successorLabel = new ItemLabel();
            successorLabel.setUuid(itemSuccessor.getUuid());
            successorLabel.setUri_name(itemSuccessor.getUriName());

            ItemClassLabel successoritemclasslabel = new ItemClassLabel();
            Itemclass itemsuccessoritemclass = itemSuccessor.getItemclass();
            successoritemclasslabel.setUuid(itemsuccessoritemclass.getUuid());
            successoritemclasslabel.setUri_name(itemsuccessoritemclass.getUriName());

            String SUCCESSOR_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE it.itemclass = :itemclass";
            Query qsl = em.createQuery(SUCCESSOR_LOCALIZATION_QUERY);
            qsl.setParameter("itemclass", itemsuccessoritemclass);
            List<Localization> itemsuccessorLocalizationList = qsl.getResultList();
            if (itemsuccessorLocalizationList.size() == 1) {
                for (Localization itemsuccessorLocalization : itemsuccessorLocalizationList) {
                    successoritemclasslabel.setLabelAttribute(itemsuccessorLocalization.getLabel(), itemsuccessorLocalization.getLanguage().getIsocode());
                }
            }
            successorLabel.setItemclass(successoritemclasslabel);
            successorItemLabel.setItemlabel(successorLabel);
            itemLabel.setSuccessor(successorItemLabel);
        }
    }

    public static Customattributevalue insertLocalizationDetail(Localization localizationitem, ItemLabel itemLabel) {
        /**
         * localization details
         */
        String localizationitemUUID = localizationitem.getUuid();
        Item localizationitemItem = localizationitem.getItem();
        Itemclass localizationitemItemClass = localizationitem.getItemclass();
        Languagecode localizationitemLanguage = localizationitem.getLanguage();
        Register localizationitemRegister = localizationitem.getRegister();
        Customattributevalue localizationitemCustomattributevalue = localizationitem.getCustomattributevalue();
        String localizationitemLabel = localizationitem.getLabel();
        String localizationitemDefinition = localizationitem.getDefinition();
        String localizationitemDescription = localizationitem.getDescription();
        Date localizationitemDatecreation = localizationitem.getDatecreation();
        Date localizationitemDatelastmodification = localizationitem.getDatelastupdate();

        itemLabel.setLabel(localizationitemLabel, localizationitemLanguage.getIsocode());
        itemLabel.setDefinition(localizationitemDefinition, localizationitemLanguage.getIsocode());
        itemLabel.setDescription(localizationitemDescription, localizationitemLanguage.getIsocode());
        itemLabel.setDatecreation(localizationitemDatecreation);
        itemLabel.setDatelastupdate(localizationitemDatelastmodification);

        return localizationitemCustomattributevalue;
    }

    public static void insertCustomAttribute(EntityManager em, Item item, ItemLabel itemLabel, Languagecode language) {
        CustomattributeLabelList customattributeLabelList = new CustomattributeLabelList();
        ArrayList<CustomattributeLabel> customattributeLabelArray = new ArrayList<CustomattributeLabel>();

        /**
         * get the itemClass
         */
        Itemclass itemclass = item.getItemclass();

        String ITEMCLASS_CUSTOMATTRIBUTE_QUERY = "SELECT ca FROM " + EntityNames.ENTITY_CUSTOMATTRIBUTE + " ca WHERE ca.itemclass = :itemclass";
        Query iccaq = em.createQuery(ITEMCLASS_CUSTOMATTRIBUTE_QUERY);
        iccaq.setParameter("itemclass", itemclass);

        List<Customattribute> customattributeList = iccaq.getResultList();
        for (Customattribute customattribute : customattributeList) {
            String customattributeUUID = customattribute.getUuid();
            boolean customattributeRequired = customattribute.getRequired();
            String customattributeName = customattribute.getName();
            boolean customattributeMultivalue = customattribute.getMultivalue();
            boolean customattributeIsforeignkKey = customattribute.getIsforeignkey();
            Date customattributeDatecreation = customattribute.getDatecreation();
            Date customattributeDatelastupdate = customattribute.getDatelastupdate();
            boolean customattributeCoded = customattribute.getCoded();

            String CUSTOMATTRIBUTEVALUE_QUERY = "SELECT cav FROM " + EntityNames.ENTITY_CUSTOMATTRIBUTEVALUE + " cav WHERE cav.item = :item AND cav.customattribute = :customattribute";
            Query cavq = em.createQuery(CUSTOMATTRIBUTEVALUE_QUERY);
            cavq.setParameter("item", item);
            cavq.setParameter("customattribute", customattribute);

            List<Customattributevalue> customattributevalueList = cavq.getResultList();
            for (Customattributevalue customattributevalue : customattributevalueList) {

                String LOCALIZATIONS_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.customattributevalue = :customattributevalue AND loc.language = :language";
                Query locq = em.createQuery(LOCALIZATIONS_QUERY);
                locq.setParameter("customattributevalue", customattributevalue);
                locq.setParameter("language", language);

                List<Localization> localizationList = locq.getResultList();
                for (Localization localization : localizationList) {
                    String localizationUUID = localization.getUuid();
                    Item localizationItem = localization.getItem();
                    Itemclass localizationItemClass = localization.getItemclass();
                    Languagecode localizationLanguage = localization.getLanguage();
                    Register localizationRegister = localization.getRegister();
                    Customattributevalue localizationCustomattributevalue = localization.getCustomattributevalue();
                    String localizationLabel = localization.getLabel();
                    String localizationDefinition = localization.getDefinition();
                    String localizationDescription = localization.getDescription();
                    Date localizationDatecreation = localization.getDatecreation();
                    Date localizationDatelastupdate = localization.getDatelastupdate();

                    CustomattributeLabel customattributeLabel = new CustomattributeLabel();
                    customattributeLabel.setName(customattributeName);
                    customattributeLabel.setRequired(customattributeRequired);
                    customattributeLabel.setMultivalue(customattributeMultivalue);
                    customattributeLabel.setIsforeignKey(customattributeIsforeignkKey);
                    customattributeLabel.setCoded(customattributeCoded);
                    customattributeLabel.setDatecreation(customattributeDatecreation);
                    customattributeLabel.setDatelastupdate(customattributeDatelastupdate);
                    customattributeLabel.setLabel(localizationLabel, localizationLanguage.getIsocode());

                    customattributeLabelArray.add(customattributeLabel);
                }
            }
        }
        customattributeLabelList.setCustomattributeLabel(customattributeLabelArray);
        itemLabel.setCustomattributeLabelList(customattributeLabelList);
    }
}
