<?xml version="1.0" encoding="UTF-8"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="footer.xsl" />
    <xsl:include href="dxbox.xsl" />
    
    <!--Properties-->
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    
    <!--Common variables-->
    <xsl:param name="base_db_export_path" />
    <xsl:variable name="register_base_uri" select="register/base_uri"/>
    <xsl:variable name="base_res_uri" select="register/base_uri" />
    <xsl:variable name="register_uri_name" select="register/uri_name"/>
    <xsl:variable name="registry_base_uri" select="register/registry/base_uri"/>
    <xsl:variable name="registry_uri_name" select="register/registry/uri_name"/>
    <xsl:variable name="registry_label" select="register/registry/label"/>
    
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>   
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
                <title>
                    <xsl:value-of select="register/label" />
                </title>
                <link rel="stylesheet" type="text/css">
                    <xsl:attribute name="href">
                        <xsl:value-of select="$base_res_uri" />
                        <xsl:text>/res/css/style.css</xsl:text>
                    </xsl:attribute>
                </link>
                
                <script type="text/javascript">
                    <xsl:attribute name="src">
                        <xsl:value-of select="$base_res_uri" />
                        <xsl:text>/res/js/jquery-1.9.1.js</xsl:text>
                    </xsl:attribute>
                </script>
                
                <script type="text/javascript">
                    <xsl:attribute name="src">
                        <xsl:value-of select="$base_res_uri" />
                        <xsl:text>/res/js/jquery-ui-1.10.1.min.js</xsl:text>
                    </xsl:attribute>
                </script>
                <script type="text/javascript">
                    <xsl:attribute name="src">
                        <xsl:value-of select="$base_res_uri" />
                        <xsl:text>/res/js/modernizr.js</xsl:text>
                    </xsl:attribute>
                </script>
            </head>
            
            <body>
                <header>
                    <div id="topright">
                        <script>
                            $("#topright").load("http://inspire.ec.europa.eu/registry/html_common/top_right.html");
                        </script>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm">European Commission</a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.jrc.ec.europa.eu/">INSPIRE</a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="$registry_base_uri"/>
                                <xsl:text>/</xsl:text>
                                <xsl:value-of select="$registry_uri_name"/>
                            </xsl:attribute>    
                            <xsl:value-of select="$registry_label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>
                            <xsl:value-of select="register/label" />
                        </span>
                    </div>
                </header>
                
                <article class="exp">
                    <xsl:apply-templates select="register"/>
                </article>
                
                <footer>
                    <xsl:call-template name="ftr" >
                        <xsl:with-param name="reglabel" select="$registry_label"/>
                    </xsl:call-template>
                </footer>
                
                <xsl:call-template name="dxbox" />
                
            </body>
        </html>
    </xsl:template>

    <xsl:template match="register">
     
        <h2>
            <xsl:value-of select="label" />
        </h2>
        
        <p>
            <span>ID:</span> 
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$register_base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>            
                </xsl:attribute>    
                <xsl:value-of select="$register_base_uri"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="$register_uri_name"/>
            </a>
        </p>
        
        <p>
            <span>Language:</span> 
            <strong>
                <xsl:value-of select="label/@language"/>
            </strong>
        </p>
        
        <xsl:if test="label != ''">
            <p>
                <span>Label:</span> 
                <strong>
                    <xsl:value-of select="label" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="owner != ''">
            <p>
                <span>Owner:</span> 
                <strong>
                    <xsl:value-of select="owner" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="manager != ''">
            <p>
                <span>Register manager:</span> 
                <strong>
                    <xsl:value-of select="manager" />
                </strong>
            </p>
        </xsl:if>        

        <xsl:if test="controlbody != ''">
            <p>
                <span>Control body:</span> 
                <strong>
                    <xsl:value-of select="controlbody" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="definition != ''">
            <p>
                <span class="csm">Content summary:</span>
            </p>
            <div class="dcsm">
                <xsl:variable name="tmp" select="definition"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>
        </xsl:if>
        
        <xsl:if test="description != ''">
            <p>
                <span class="csm">Description:</span>
            </p>    
            <div class="dcsm">
                <xsl:variable name="tmp" select="description"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>            
        </xsl:if>
        
        <p>
            <span>Registry:</span> 
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="registry/base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="registry/uri_name"/>
                </xsl:attribute>
                <xsl:value-of select="registry/base_uri"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="registry/uri_name"/>
            </a>
        </p>
        
        <xsl:if test="items != ''">
            <br/>
            <h3>Code list</h3>
        
            <div class="tb_cont">
                <table>
                    <tr>
                        <th>ID</th>
                        <th>Label</th>
                        <th>Status</th>
                    </tr>            
                    <xsl:for-each select="items/item">                
                        <tr>
                            <td>
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="$register_base_uri"/>
                                        <xsl:text>/</xsl:text>
                                        <xsl:value-of select="$register_uri_name"/>
                                        <xsl:text>/</xsl:text>
                                        <xsl:value-of select="uri_name"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="$register_base_uri"/>
                                    <xsl:text>/</xsl:text>
                                    <xsl:value-of select="$register_uri_name"/>
                                    <xsl:text>/</xsl:text>
                                    <xsl:value-of select="uri_name"/>
                                </a>  
                            </td>                    
                            <td>
                                <xsl:value-of select="label" />
                            </td>     
                            <td>
                                <xsl:value-of select="status/label" />
                                <br/>
                                <a>
                                    <xsl:attribute name="href" select="status/uri"/>
                                    <xsl:value-of select="status/uri"/>
                                </a>
                            </td>
                        </tr>
                    </xsl:for-each>
                </table>
            </div>
        </xsl:if>    
    </xsl:template>
</xsl:stylesheet>