/*
* Copyright 2010,2013 EUROPEAN UNION
* Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
* the European Commission - subsequent versions of the EUPL (the "Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
*
* http://ec.europa.eu/idabc/eupl
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the Licence is distributed on an "AS IS" basis,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the Licence for the specific language governing permissions and
* limitations under the Licence.
*
* Date: 14/06/2013
* Authors: European Commission, Joint Research Centre
* Daniele Francioli, Emanuela Epure
* inspire-registry-info@jrc.ec.europa.eu
*
* This work was supported by the EU  Interoperability Solutions for
* European Public Administrations Programme (http://ec.europa.eu/isa)
* through Action 1.17: Re-usable INSPIRE Reference Platform 
* (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
*/
 
package eu.europa.ec.re3gistry.re3gistryimport.servlet;

import eu.europa.ec.re3gistry.re3gistryimport.constants.Constants;
import eu.europa.ec.re3gistry.re3gistryimport.manager.ImportMgr;
import java.io.IOException;
import java.util.List;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.apache.log4j.Logger;

public class ImportEngine extends HttpServlet {

    private static final long serialVersionUID = 1L;
    private static Logger log = Logger.getLogger(ImportEngine.class);
    private static final String VALUE_WEB_FORM_FIELD_ACTION = "action";
    private static final String VALUE_WEB_FORM_FIELD_REGISTERUUID = "register";
    private static final String VALUE_WEB_FORM_FIELD_ITEMCLASSUUID = "itemclass";
    private static final String VALUE_WEB_FORM_FIELD_LANGUAGECODE = "languagecode";
    private static final String VALUE_WEB_FORM_FIELD_ITEMCLASSUUID_COLLECTION = "itemclass-collection";
    private static final String VALUE_RERIDECT_TARGET = "/index.jsp";
    private ImportMgr imgr;

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        int importedItem = 0;
        int importedLanguage = 0;

        log.info("####");
        log.info("#### Import procedure ####");

        try {
            //Istantiating the import manager
            imgr = new ImportMgr();

            //Getting web form fields
            List<FileItem> fl = new ServletFileUpload(new DiskFileItemFactory()).parseRequest(request);
            int action = 0;
            String registerUuid = null;
            String itemclassUuid = null;
            String itemclassCollectionUuid = null;
            String languagecodeUuid = null;
            FileItem importFile = null;
            for (FileItem item : fl) {
                if (item.isFormField() && item.getFieldName().equals(VALUE_WEB_FORM_FIELD_ACTION)) {
                    action = Integer.parseInt(item.getString());
                } else if (item.isFormField() && item.getFieldName().equals(VALUE_WEB_FORM_FIELD_ITEMCLASSUUID)) {
                    itemclassUuid = item.getString();
                } else if (item.isFormField() && item.getFieldName().equals(VALUE_WEB_FORM_FIELD_REGISTERUUID)) {
                    registerUuid = item.getString();
                } else if (item.isFormField() && item.getFieldName().equals(VALUE_WEB_FORM_FIELD_LANGUAGECODE)) {
                    languagecodeUuid = item.getString();
                } else if (item.isFormField() && item.getFieldName().equals(VALUE_WEB_FORM_FIELD_ITEMCLASSUUID_COLLECTION)) {
                    itemclassCollectionUuid = item.getString();
                } else if (!item.isFormField()) {
                    importFile = item;
                }
            }

            //Checking if the import file is not null
            if (importFile != null && importFile.getSize() != 0) {
                //Calling the specific import based on importType (specified in the request's web webform)
                if (action == Constants.ACTION_TYPE_ITEMIMPORT) {
                    log.info("Starting item import;");
                    importedItem = imgr.startImport(Constants.ACTION_TYPE_ITEMIMPORT, registerUuid, itemclassUuid, itemclassCollectionUuid, languagecodeUuid, importFile, request, response);
                    log.info("Starting language import;");
                    importedLanguage = imgr.startImport(Constants.ACTION_TYPE_LANGUAGEIMPORT, registerUuid, itemclassUuid, itemclassCollectionUuid, languagecodeUuid, importFile, request, response);
                } else if (action == Constants.ACTION_TYPE_LANGUAGEIMPORT) {
                    log.info("Starting language import;");
                    importedLanguage = imgr.startImport(Constants.ACTION_TYPE_LANGUAGEIMPORT, registerUuid, itemclassUuid, itemclassCollectionUuid, languagecodeUuid, importFile, request, response);
                } else {
                    log.info("Warning: no action found; could not execute the request.");
                }
            } else {
                log.info("Warning: the import file was not found or the file was empty; could not execute the request.");
            }
        } catch (FileUploadException e) {
            log.error("There was an error while uploading files.", e);
        } catch (Exception e) {
            log.error("There was a generic error while executing the request.", e);
        }

        log.info("#### Import procedure finished ####");
        log.info("####");
        log.info("");

        RequestDispatcher rd;
        rd = getServletContext().getRequestDispatcher(VALUE_RERIDECT_TARGET);
        request.setAttribute("importedRows", importedItem);
        request.setAttribute("importedLanguage", importedLanguage);
        rd.forward(request, response);
    }
}